@@ -1,10 +1,10 @@
 from collections import OrderedDict
-from copy import deepcopy
+from copy import deepcopy, copy
 from functools import singledispatch
 from itertools import groupby
 from typing import Callable, Dict, List, Any
 import pprint
-from .types import KT, VT
+from .types import KT, VT, PROFILE_GLOBAL
 
 
 def inspect(obj):
@@ -27,7 +27,7 @@ def list_uniq(a: List) -> List:
 def dict_merge(
     a: Dict[KT, VT], b: Dict[KT, VT], f: Callable[[VT, VT], VT]
 ) -> Dict[KT, VT]:
-    merged = deepcopy(a)
+    merged = copy(a)
     for k in b.keys():
         if k in merged.keys():
             merged[k] = f(a[k], b[k])
@@ -36,6 +36,26 @@ def dict_merge(
     return merged
 
 
+def dict_merge_with_wildcard(a, b, f):
+    if b is None:
+        return a
+
+    merged = copy(b)
+    wb = b.get(PROFILE_GLOBAL, None)
+    for k in a.keys():
+        if k in b.keys():
+            merged[k] = f(a[k], b[k])
+        else:
+            merged[k] = f(a[k], wb)
+
+    wa = a.get(PROFILE_GLOBAL, None)
+    if wa is not None:
+        for k in b.keys():
+            if k not in a.keys():
+                merged[k] = f(wa, b[k])
+    return merged
+
+
 @singledispatch
 def config_merger(_, b):
     return b
